@@ -1,7 +1,7 @@
 """Implementation of postgres backends."""
 
 from dinao.backend.base import Connection, ConnectionPool
-from dinao.backend.errors import BackendEngineNotInstalled, ConfigurationError
+from dinao.backend.errors import BackendNotInstalledError, ConfigurationError
 
 
 class ConnectionPSQLPsycopg2(Connection):
@@ -19,40 +19,33 @@ class ConnectionPoolPSQLPsycopg2(ConnectionPool):
 
         The db_url is expected to be in the following format::
 
-            "postgres+psycopg2://{username}:{password}@{hostname}:{port}/{db_name}?{optional_ars}"
+            "postgres+psycopg2://{username}:{password}@{hostname}:{port}/{db_name}?{optional_args}"
 
-        Supported `optional_ars` include:
+        Supported `optional_args` include:
 
-            * schema, sets the search path of the connections, defaults to "public"
+            * schema, a list of strings that sets the search path of the connections, defaults to "public"
             * pool_min_conn, an integer specifying the minimum connections to keep in the pool, defaults to 1
             * pool_max_conn, an integer specifying the maximum connections to keep in the pool, defaults to 1
             * pool_threaded, a boolean specifying a threaded pool should be used, defaults to False
 
         :param db_url: a url with the described format
-        :raises: ConfigurationError, BackendEngineNotInstalled
+        :raises: ConfigurationError, BackendNotInstalledError
         """
         super().__init__(db_url)
         try:
             import psycopg2.pool
         except ModuleNotFoundError:  # pragma: no cover
             issue = "Module psycopg2 not installed, cannot create connection pool"
-            raise BackendEngineNotInstalled(issue)
-        self._cnx_kwargs = self._mk_cnx_kwargs()
+            raise BackendNotInstalledError(issue)
+        self._cnx_kwargs = self._make_cnx_kwargs()
         self._pool_class = psycopg2.pool.SimpleConnectionPool
         if self._get_arg("pool_threaded", bool, False):
             self._pool_class = psycopg2.pool.ThreadedConnectionPool
         self._pool_impl = None
         self._raise_for_unexpected_args()
-        if not self._defer_pool:
-            assert self._pool
+        self._pool = self._pool_class(**self._cnx_kwargs)
 
-    @property
-    def _pool(self):
-        if self._pool_impl is None:
-            self._pool_impl = self._pool_class(**self._cnx_kwargs)
-        return self._pool_impl
-
-    def _mk_cnx_kwargs(self):
+    def _make_cnx_kwargs(self):
         dbname = self._db_url.path.strip("/")
         if not dbname:
             raise ConfigurationError("Database name is required but missing")
@@ -79,6 +72,10 @@ class ConnectionPoolPSQLPsycopg2(ConnectionPool):
     def release(self, cnx: Connection):  # noqa: D102
         self._pool.putconn(cnx._cnx)
 
+    def dispose(self):  # noqa: D102
+        if not self._pool.closed:
+            self._pool.closeall()
+
     @property
     def mung_symbol(self) -> str:  # noqa: D102
         return "%s"
