@@ -1,4 +1,5 @@
 """Implementation of SQLite backends."""
+import os.path
 import sqlite3
 
 from dinao.backend.base import Connection, ConnectionPool
@@ -27,14 +28,15 @@ class ConnectionPoolSQLite3(ConnectionPool):
         Obviously, this is not a real "pool", all connections given out by lease will be new connections.
 
         :param db_url: a url with the described format
-        :raises: ConfigurationError, BackendEngineNotInstalled
+        :raises: ConfigurationError, BackendNotInstalledError
         """
         super().__init__(db_url)
-        self._cnx_kwargs = self._url_to_cnx_kwargs(db_url)
+        self._cnx_kwargs = self._url_to_cnx_kwargs()
         self._raise_for_unexpected_args()
 
-    def _url_to_cnx_kwargs(self, url: str):
-        return {"database": self._db_url.path}
+    def _url_to_cnx_kwargs(self):
+        file_path = os.path.abspath(os.path.expanduser(self._db_url.path))
+        return {"database": file_path}
 
     def lease(self) -> Connection:  # noqa: D102
         inner_cnx = sqlite3.connect(**self._cnx_kwargs)
@@ -43,6 +45,9 @@ class ConnectionPoolSQLite3(ConnectionPool):
     def release(self, cnx: Connection):  # noqa: D102
         cnx._cnx.close()
 
+    def dispose(self):  # noqa: D102
+        return
+
     @property
     def mung_symbol(self) -> str:  # noqa: D102
         return "?"
